Type: Package
Package: rpf
Title: Response Probability Functions
Version: 1.0.15
Date: 2025-05-03
Authors@R: 
    c(person(given = "Joshua",
             family = "Pritikin",
             role = c("cre", "aut"),
             email = "jpritikin@pobox.com"),
      person(given = "Jonathan",
             family = "Weeks",
             role = "ctb",
             email = "weeksjp@gmail.com"),
      person(given = "Li",
             family = "Cai",
             role = "ctb"),
      person(given = "Carrie",
             family = "Houts",
             role = "ctb"),
      person(given = "Phil",
             family = "Chalmers",
             role = "ctb",
             email = "rphilip.chalmers@gmail.com"),
      person(given = c("Michael", "D."),
             family = "Hunter",
             role = "ctb"),
      person(given = c("Carl", "F."),
             family = "Falk",
             role = "ctb",
             email = "falkcarl@msu.edu"))
Maintainer: Joshua Pritikin <jpritikin@pobox.com>
Description: Factor out logic
    and math common to Item Factor Analysis fitting, diagnostics, and
    analysis. It is envisioned as core support code suitable for more
    specialized IRT packages to build upon. Complete access to optimized C
    functions are made available with R_RegisterCCallable().
    This software is described in Pritikin & Falk (2020) <doi:10.1177/0146621620929431>.
License: GPL (>= 3)
URL: https://github.com/jpritikin/rpf
Depends: methods, parallel, R (>= 2.14.0)
Imports: Rcpp (>= 1.0.2), mvtnorm, lifecycle
Suggests: testthat, roxygen2, ggplot2, reshape2, gridExtra, numDeriv,
        knitr, mirt, markdown
LinkingTo: Rcpp, RcppEigen
VignetteBuilder: knitr
RdMacros: lifecycle
Encoding: UTF-8
LazyData: yes
LazyDataCompression: xz
RoxygenNote: 7.3.2
SystemRequirements: GNU make
Collate: 'init.R' 'classes.R' 'fit.R' 'drm.R' 'nrm.R' 'mcm.R' 'grm.R'
        'LSAT.R' 'sample.R' 'dataframe.R' 'diagnose.R' 'science.R'
        'kct.R' 'openmx.R' 'flexmirt.R' 'util.R' 'lmp.R' 'grmp.R'
        'gpcmp.R' 'RcppExports.R'
NeedsCompilation: yes
Packaged: 2025-05-04 06:15:04 UTC; joshua
Author: Joshua Pritikin [cre, aut],
  Jonathan Weeks [ctb],
  Li Cai [ctb],
  Carrie Houts [ctb],
  Phil Chalmers [ctb],
  Michael D. Hunter [ctb],
  Carl F. Falk [ctb]
Repository: CRAN
Date/Publication: 2025-05-04 10:00:02 UTC
Built: R 4.6.0; aarch64-apple-darwin23; 2026-04-25 23:21:08 UTC; unix
Archs: rpf.so.dSYM
