import(methods)
import(parallel)
importFrom("stats", "integrate", "na.omit", "pchisq", "rbeta",
	   "rlnorm", "rnorm", "runif", "uniroot")
importFrom("utils", "count.fields", "read.delim")
importFrom(Rcpp, evalCpp)
importFrom(lifecycle, deprecate_soft)
exportClassPattern("^rpf.+")
exportMethods(rpf.logprob)
exportMethods(rpf.prob)
exportMethods(rpf.rparam)
exportPattern("^rpf.+")
export(read.flexmirt)
export(write.flexmirt)
export(chen.thissen.1997)  # old name
export(ChenThissen1997)
export(ordinal.gamma)
export(ptw2011.gof.test)
export(logit)
export(sumScoreEAP)
export(crosstabTest)
export(SitemFit)
export(SitemFit1)
export(observedSumScore)
export(itemOutcomeBySumScore)
export(orderCompletely)
export(tabulateRows)
export(expandDataFrame)
export(compressDataFrame)
export(multinomialFit)
export(EAPscores)
export(as.IFAgroup)
export(stripData)
export(sumScoreEAPTest)
export(bestToOmit)
export(omitItems)
export(omitMostMissing)
export(toFactorLoading)
export(fromFactorLoading)
export(toFactorThreshold)
export(fromFactorThreshold)
export(collapseCategoricalCells)
S3method(print, summary.ChenThissen1997)
S3method("+", summary.ChenThissen1997)
S3method(print, summary.SitemFit)
S3method("+", summary.SitemFit)
S3method(print, summary.sumScoreEAPTest)
S3method("+", summary.sumScoreEAPTest)
S3method(print, summary.itemOutcomeBySumScore)
S3method(print, summary.observedSumScore)
S3method(print, summary.multinomialFit)
useDynLib(rpf, .registration = TRUE)
