##' Liking for Science dataset
##'
##' These data are from Wright & Masters (1982, p. 18).
##' 
##' All items were fit to a 3 category Partial Credit Model (PCM)
##' using Ministep 3.75.0.
##'
##' @docType data
##' @keywords data
##' @name science
##' @aliases sfif sfpf sfsf sfxf
##' @references Wright, B. D. & Masters, G. N. (1982). \emph{Rating Scale
##' Analysis.} Chicago: Mesa Press.
##' @examples
##' data(science)
NULL
