##' Knox Cube Test dataset
##'
##' These data from Wright & Stone (1979, p. 31) were fit with
##' Winsteps 3.73 using a 1PL model (slope fixed to 1).
##'
##' @docType data
##' @keywords data
##' @name kct
##' @aliases kct.items kct.people
##' @references
##' Wright, B. D. & Stone, M. H. (1979). \emph{Best Test Design: Rasch Measurement.} Univ of Chicago Social Research.
##' @examples
##' data(kct)
NULL
