# Generated by using Rcpp::compileAttributes() -> do not edit by hand
# Generator token: 10BE3573-1514-4C36-9D1C-5A225CD40393

findIdenticalRowsData <- function(data, missing, defvars, skipMissingness, skipDefvars) {
    .Call(`_rpf_findIdenticalRowsData`, data, missing, defvars, skipMissingness, skipDefvars)
}

ot2000 <- function(robj, iPlusOne, alter, mask, twoTier) {
    .Call(`_rpf_ot2000`, robj, iPlusOne, alter, mask, twoTier)
}

ssEAP_wrapper <- function(robj, Rmask, twoTier) {
    .Call(`_rpf_ssEAP_wrapper`, robj, Rmask, twoTier)
}

pairwiseExpected_cpp <- function(robj, items, twoTier) {
    .Call(`_rpf_pairwiseExpected_cpp`, robj, items, twoTier)
}

collapse <- function(r_observed_orig, r_expected_orig, r_min) {
    .Call(`_rpf_collapse`, r_observed_orig, r_expected_orig, r_min)
}

fast_tableWithWeights <- function(Ritem1, Ritem2, Rweight) {
    .Call(`_rpf_fast_tableWithWeights`, Ritem1, Ritem2, Rweight)
}

observedSumScore_cpp <- function(Rgrp, Rmask) {
    .Call(`_rpf_observedSumScore_cpp`, Rgrp, Rmask)
}

itemOutcomeBySumScore_cpp <- function(Rgrp, Rmask, interestPlusOne) {
    .Call(`_rpf_itemOutcomeBySumScore_cpp`, Rgrp, Rmask, interestPlusOne)
}

gamma_cor <- function(mat) {
    .Call(`_rpf_gamma_cor`, mat)
}

crosstabTest_cpp <- function(Robserved, Rexpected, trials) {
    .Call(`_rpf_crosstabTest_cpp`, Robserved, Rexpected, trials)
}

eap_wrapper <- function(Rgrp) {
    .Call(`_rpf_eap_wrapper`, Rgrp)
}

get_model_id <- function(str) {
    .Call(`_rpf_get_model_id`, str)
}

numSpec <- function(spec) {
    .Call(`_rpf_numSpec`, spec)
}

numParam <- function(spec) {
    .Call(`_rpf_numParam`, spec)
}

paramInfo <- function(spec, pnum) {
    .Call(`_rpf_paramInfo`, spec, pnum)
}

prob <- function(spec, r_param, r_theta) {
    .Call(`_rpf_prob`, spec, r_param, r_theta)
}

logprob <- function(spec, r_param, r_theta) {
    .Call(`_rpf_logprob`, spec, r_param, r_theta)
}

dLL <- function(spec, r_param, r_where, r_weight) {
    .Call(`_rpf_dLL`, spec, r_param, r_where, r_weight)
}

dTheta <- function(spec, r_param, r_where, r_dir) {
    .Call(`_rpf_dTheta`, spec, r_param, r_where, r_dir)
}

rescale <- function(spec, r_param, r_mean, r_cov) {
    .Call(`_rpf_rescale`, spec, r_param, r_mean, r_cov)
}

has_openmp <- function() {
    .Call(`_rpf_has_openmp`)
}

setNumberOfCores <- function(num) {
    .Call(`_rpf_setNumberOfCores`, num)
}

registerCCallable <- function() {
    invisible(.Call(`_rpf_registerCCallable`))
}

CaiHansen2012_cpp <- function(Rgrp, Rmethod, twotier) {
    .Call(`_rpf_CaiHansen2012_cpp`, Rgrp, Rmethod, twotier)
}

